pub enum AnalyticPrimsDescriptor {
PointwiseUnary {
op: AnalyticUnaryOp,
},
PointwiseBinary {
op: AnalyticBinaryOp,
},
Reduction {
modes_a: Vec<u32>,
modes_c: Vec<u32>,
op: AnalyticReductionOp,
},
}Expand description
Descriptor for analytic-pointwise and analytic-reduction planning.
Examples
use tenferro_prims::{AnalyticPrimsDescriptor, AnalyticUnaryOp};
let desc = AnalyticPrimsDescriptor::PointwiseUnary {
op: AnalyticUnaryOp::Sqrt,
};
assert!(matches!(desc, AnalyticPrimsDescriptor::PointwiseUnary { .. }));Variants
PointwiseUnary
Apply an analytic unary pointwise operation to one input tensor.
Fields

op: AnalyticUnaryOpThe unary analytic operation to apply.
PointwiseBinary
Apply an analytic binary pointwise operation to two input tensors.
Fields

op: AnalyticBinaryOpThe binary analytic operation to apply.
Reduction
Reduce one tensor into an output tensor over the dropped modes.