pub enum MetadataCastPrimsDescriptor {
PointwiseCast {
input_dtype: MetadataDType,
},
Where {
cond_dtype: MetadataDType,
},
}Expand description
Metadata-to-scalar bridge planning operations.
Examples
use tenferro_prims::{MetadataCastPrimsDescriptor, MetadataDType};
let cast = MetadataCastPrimsDescriptor::PointwiseCast {
input_dtype: MetadataDType::Bool,
};
assert!(matches!(cast, MetadataCastPrimsDescriptor::PointwiseCast { .. }));Variants
PointwiseCast
Cast a metadata tensor into a scalar tensor of the backend’s scalar dtype.
Fields

input_dtype: MetadataDTypeLogical dtype of the metadata input.
Where
Select between scalar tensors using a bool metadata mask.
Fields

cond_dtype: MetadataDTypeLogical dtype of the condition/mask metadata input.