MetadataPrimsDescriptor

Enum MetadataPrimsDescriptor 

pub enum MetadataPrimsDescriptor {
    Generate {
        op: MetadataGenerateOp,
        output_dtype: MetadataDType,
    },
    Binary {
        op: MetadataBinaryOp,
        lhs_dtype: MetadataDType,
        rhs_dtype: MetadataDType,
        output_dtype: MetadataDType,
    },
    Ternary {
        op: MetadataTernaryOp,
        cond_dtype: MetadataDType,
        lhs_dtype: MetadataDType,
        rhs_dtype: MetadataDType,
        output_dtype: MetadataDType,
    },
    Reduction {
        modes_a: Vec<u32>,
        modes_c: Vec<u32>,
        input_dtype: MetadataDType,
        output_dtype: MetadataDType,
        op: MetadataReductionOp,
    },
}
Descriptor for metadata tensor planning.

Examples

use tenferro_prims::{
    MetadataConstantValue, MetadataDType, MetadataGenerateOp, MetadataPrimsDescriptor,
};

let desc = MetadataPrimsDescriptor::Generate {
    op: MetadataGenerateOp::Constant(MetadataConstantValue::I32(3)),
    output_dtype: MetadataDType::I32,
};
assert!(matches!(desc, MetadataPrimsDescriptor::Generate { .. }));

Variants



Generate

Generate a metadata tensor without consuming an input tensor.

Fields

op: MetadataGenerateOp

Generation operation to apply.

output_dtype: MetadataDType

Logical dtype of the generated tensor.



Binary

Apply a metadata binary operation to two input tensors.

Fields

op: MetadataBinaryOp

Binary operation to apply.

lhs_dtype: MetadataDType

Logical dtype of the left-hand side operand.

rhs_dtype: MetadataDType

Logical dtype of the right-hand side operand.

output_dtype: MetadataDType

Logical dtype of the output tensor.



Ternary

Apply a metadata ternary operation to three input tensors.

Fields

op: MetadataTernaryOp

Ternary operation to apply.

cond_dtype: MetadataDType

Logical dtype of the condition/mask input.

lhs_dtype: MetadataDType

Logical dtype of the first data input.

rhs_dtype: MetadataDType

Logical dtype of the second data input.

output_dtype: MetadataDType

Logical dtype of the output tensor.



Reduction

Reduce one tensor into an output tensor over the dropped modes.

Fields

modes_a: Vec<u32>

Input modes associated with the source tensor.

modes_c: Vec<u32>

Output modes that remain after reduction.

input_dtype: MetadataDType

Logical dtype of the input tensor.

output_dtype: MetadataDType

Logical dtype of the output tensor.

op: MetadataReductionOp

Reduction operator to use.