MetadataTensorRef

Enum MetadataTensorRef 

pub enum MetadataTensorRef<'a> {
    I32(&'a Tensor<i32>),
    Bool(&'a Tensor<u8>),
}
Erased immutable metadata tensor reference.

The contract is intentionally narrow and only admits integer metadata and logical bool metadata. The bool handle is currently backed by u8 storage, but that is a provisional implementation detail.

Examples

use tenferro_device::LogicalMemorySpace;
use tenferro_prims::{MetadataDType, MetadataTensorRef};
use tenferro_tensor::{MemoryOrder, Tensor};

let tensor = Tensor::<i32>::zeros(
    &[2, 2],
    LogicalMemorySpace::MainMemory,
    MemoryOrder::ColumnMajor,
);
let metadata = MetadataTensorRef::I32(&tensor);
assert_eq!(metadata.dtype(), MetadataDType::I32);

Variants



I32(&'a Tensor<i32>)

A metadata tensor stored as i32.



Bool(&'a Tensor<u8>)

A logical bool/mask metadata tensor backed by u8 for now.

Implementations

Source

impl<'a> MetadataTensorRef<'a>

pub const fn dtype(&self) -> MetadataDType

Return the logical dtype carried by this metadata tensor reference.

Examples
use tenferro_device::LogicalMemorySpace;
use tenferro_prims::{MetadataDType, MetadataTensorRef};
use tenferro_tensor::{MemoryOrder, Tensor};

let tensor = Tensor::<u8>::zeros(
    &[1],
    LogicalMemorySpace::MainMemory,
    MemoryOrder::ColumnMajor,
);
let metadata = MetadataTensorRef::Bool(&tensor);
assert_eq!(metadata.dtype(), MetadataDType::Bool);