RngPrimsDescriptor

Enum RngPrimsDescriptor 

pub enum RngPrimsDescriptor {
    Uniform,
    Normal,
    Integer {
        low: i32,
        high: i32,
    },
}
Random-number generation descriptors for dense eager tensor construction.

Examples

use tenferro_prims::RngPrimsDescriptor;

let desc = RngPrimsDescriptor::Uniform;
assert!(matches!(desc, RngPrimsDescriptor::Uniform));

Variants



Uniform

Fill the output tensor with samples from the half-open interval [0, 1).



Normal

Fill the output tensor with standard normal samples.



Integer

Fill the output tensor with integer samples from the half-open interval [low, high).

Fields

low: i32

Inclusive lower bound.

high: i32

Exclusive upper bound.