pub enum ScalarPrimsDescriptor {
PointwiseUnary {
op: ScalarUnaryOp,
},
PointwiseBinary {
op: ScalarBinaryOp,
},
PointwiseTernary {
op: ScalarTernaryOp,
},
Reduction {
modes_a: Vec<u32>,
modes_c: Vec<u32>,
op: ScalarReductionOp,
},
}Expand description
Descriptor for scalar-pointwise and scalar-reduction planning.
Examples
use tenferro_prims::{ScalarPrimsDescriptor, ScalarUnaryOp};
let desc = ScalarPrimsDescriptor::PointwiseUnary {
op: ScalarUnaryOp::Reciprocal,
};
assert!(matches!(desc, ScalarPrimsDescriptor::PointwiseUnary { .. }));Variants
PointwiseUnary
Apply a unary pointwise operation to one input tensor.
Fields

op: ScalarUnaryOpThe unary scalar operation to apply.
PointwiseBinary
Apply a binary pointwise operation to two input tensors.
Fields

op: ScalarBinaryOpThe binary scalar operation to apply.
PointwiseTernary
Apply a ternary pointwise operation to three input tensors.
Fields

op: ScalarTernaryOpThe ternary scalar operation to apply.
Reduction
Reduce one tensor into an output tensor over the dropped modes.