pub enum SortPrimsDescriptor {
Sort {
axis: usize,
descending: bool,
stable: bool,
},
Argsort {
axis: usize,
descending: bool,
stable: bool,
},
Topk {
axis: usize,
k: usize,
largest: bool,
sorted: bool,
},
}Expand description
Descriptor for sort-family planning.
Examples
use tenferro_prims::SortPrimsDescriptor;
let desc = SortPrimsDescriptor::Sort {
axis: 0,
descending: false,
stable: true,
};
assert!(matches!(desc, SortPrimsDescriptor::Sort { .. }));
let desc = SortPrimsDescriptor::Topk {
axis: 0,
k: 3,
largest: true,
sorted: true,
};
assert!(matches!(desc, SortPrimsDescriptor::Topk { .. }));Variants
Sort
Sort elements along axis.
Produces both sorted values and the corresponding permutation indices.
Fields
Argsort
Compute the permutation that would sort elements along axis.
Returns only the index permutation (values output is left unmodified).
Fields
Topk
Select the top-k elements along axis.
Returns the k largest (or smallest) values and their indices.